#' Estimate kappas and their standard deviations
#'
#' **Note:** This function uses counting, which is probably inefficient if
#'    the data is continuous.
#'
#' @param x A matrix of ratings in wide form. Fleiss form not supported.
#' @param disagreement The type of disagreement measure used.
#' @param type The type of disagreement measure used. Defaults to `cohen`.
#' @param g The arity of the disagreement function.
#' @return A list contain the estimate `kappa_hat` and `sigma_hat`,
#'   the estimated standard deviation.
#' @keywords internal
kappa_calc <- function(x, disagreement, type, g = 2) {
  disagreements <- c("nominal", "absolute", "quadratic", "hubert")
  d <- which(disagreement == disagreements) - 1
  uniques <- sort(unique(c(x)))
  mus <- if (type == "fleiss") {
    counts <- Rfast::Table(x)
    pk_ <- unname(counts / (nrow(x) * ncol(x)))
    pk <- matrix(rep(pk_, ncol(x)), nrow = length(uniques))
    mus_fleiss_cpp(x, uniques, pk, g, d)
  } else {
    pk <- (apply(x, 2, \(y) Rfast::Table(c(y, uniques))) - 1) / nrow(x)
    r_combs <- arrangements::combinations(ncol(x), g) - 1
    mus_cohen_cpp(x, uniques, pk, g, d, r_combs)
  }
  muds <- muds_simple_cpp(x, g, d)
  est_and_sd(muds, mus, g)
}


