.weights = c("unit", "quadratic", "abs")
#' Check the input to `w`
#'
#' Throws an error if `w` is not a string in `.weights` and
#'    `w` is not a function.
#'
#' @param w Supplied `w`.
#' @return `TRUE` if w is a valid string.

is_w_string = function(w) {
  if(!is.function(w)) {
    if(!(w %in% .weights)) {
      stop(paste0("The `w` argument must be either a weighting function or one of '",
                  paste0(.weights, collapse = "','"), "'."))
    } else {
      TRUE
    }
  } else {
    FALSE
  }

}

#' Transforms string to function.
#'
#' @param w Supplied `w`.
#' @return The function associated with w.
string_to_function = function(w) {
  w = match.arg(w, choices = .weights)
  if(w == "quadratic") {
    function(x,y) 1 - (x - y)^2
  } else if (w == "abs") {
    function(x,y) 1 - abs(x - y)
  } else if (w == "unit") {
    function(x,y) x == y
  }
}