% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ac1.R
\name{ac1}
\alias{ac1}
\title{Calculate the generalized AC1 coefficient.}
\usage{
ac1(
  x,
  alternative = c("two.sided", "greater", "less"),
  conf_level = 0.95,
  method = c("plugin", "empirical", "gwet"),
  model = c("bp", "fleiss"),
  gamma = 0,
  skip = FALSE,
  cat = length(unique(c(x)))
)
}
\arguments{
\item{x}{An array of raw data. Each row corresponds to an item and
each column corresponds to a judge. (CHANGE TO KRIPPENDORFF FORM.)}

\item{alternative}{a character string specifying the alternative hypothesis,
must be one of \code{"two.sided"} (default), \code{"greater"} or \code{"less"}. Used both
for the test and the confidence interval.}

\item{conf_level}{Confidence level for the confidence interval. Defaults to
to \code{0.95}.}

\item{method}{The estimation method. Either \code{"plugin"}, \code{"ml"}, or \code{"gwet"}.
Defaults to \code{"plugin"}, which works both for the Fleiss and Gwet models.
The option \code{"gwet"} uses the approximation method of Gwet (2008), and is
not recommended.}

\item{model}{The model used in the estimation of the coefficient. The
\code{"general"} model makes no additional assumptions. The \code{"cxf"} (Cohen-x-Fleiss)
model assumes the true distribution equals the marginal distribution.
The \code{"equality"} model assumes all guessing distributions are equal.
\code{"bp"}model assumes that the guessing distribution is uniform, the
\code{"fleiss"} model assumes that the guessing distribution equals the
marginal distribution of ratings.}

\item{gamma}{The AC1 coefficient of the null-hypothesis. Defaults to \code{0},
which is the minimal value the AC1 coefficient.}

\item{skip}{If \code{TRUE}, skips boostrapping and only calcutes the AC1
coefficient. Defaults to \code{FALSE}}

\item{cat}{Number of categories. Defaults the number of unique values in the
data.}
}
\value{
A list with class \code{"htest"} containing the following components:
\describe{
\item{\code{statistic}}{the value of the test statistic.}
\item{\code{p.value}}{the p-value for the test.}
\item{\code{conf.int}}{a confidence interval for the mean appropriate to the
specified alternative hypothesis.}
\item{\code{estimate}}{the estimated AC1 coefficient.}
\item{\code{null.value}}{the specified hypothesized value of the AC1
coefficient.}
\item{\code{stderrr}}{the standard error of the estimator.}
\item{\code{alternative}}{a character string describing the alternative
hypothesis.}
\item{\code{method}}{a character string indicating if \code{"plugin"} or \code{"bp"}
was used and the model used (either  \code{"bp"} or \code{"fleiss"}.)}
\item{\code{data.name}}{a character string giving the name of the data.}
}
}
\description{
Estimate, calculate confidence intervals, and perform hypothesis tests
for the generalized AC1 coefficient.
}
\details{
The confidence interval and hypothesis test is calculated using asymptotic theory
for the \code{plugin} estimator under the \code{"bp"} model; otherwise the
bias-corrected and accelerated boostrap is used. For the confidence interval
construction of Gwet (2008), see \verb{[irrCAC::gwet.ac1.dist]}.

RIGHT NOW ONLY PLUGIN WITH \code{"bp"} IS IMPLEMENTED!

The output is modelled after the tests in the \code{stats} package, e.g.
\code{stats::prop.test} and \code{stats::t.test}.
}
\examples{
  # Using the default plugin method.
  ac1(triplet_to_raw(dat.zapf2016))

  # Using Gwet's approximation method.
  # ac1(triplet_to_raw(dat.zapf2016), method = "gwet")
}
\references{
Efron, B. (1987). Better Bootstrap Confidence Intervals. Journal of the
American Statistical Association, 82(397), 171–185.
https://doi.org/10.2307/2289144

Gwet, K. L. (2014). Handbook of Inter-Rater Reliability.
Advanced Analytics, LLC.

Gwet, K. L. (2008). Computing inter-rater reliability and its variance in
the presence of high agreement. The British Journal of Mathematical and
Statistical Psychology, 61, 29–48.
https://doi.org/10.1348/000711006X126600

van Oest, R. (2019). A new coefficient of interrater agreement: The
challenge of highly unequal category proportions. Psychological Methods,
24(4), 439–451. https://doi.org/10.1037/met0000183
}
