% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/agreement.R
\name{agreement}
\alias{agreement}
\title{Calculate the sample agreement coefficient}
\usage{
agreement(x, loss = function(x, y) x != y)
}
\arguments{
\item{x}{Agreement data on triplet form; see the details.}

\item{loss}{The loss function to use. Must be symmetric.}
}
\value{
The sample agreement coefficient.
}
\description{
The sample agreement coefficient equals the sample Cohen's kappa when there
are two raters and no missing values. It equals Krippendorff's \link{alpha} when
every judge rates one item and every item is judge exactly twice. It
equals the sample \link{pi} when the marginals for all the judges are the same.
}
\details{
\code{agreement} takes its input data on triplet form. This is a data frame with
three columns: \code{rating}, \code{item}, \code{judge}. Repeated item-judge pairs are
currently not supported. That is, every judge rates every item at most
once. You may convert raw data to triplet form data using the function
\link{transform_data}.
}
\references{
Cohen, J. (1968). Weighted kappa: Nominal scale agreement with provision for
scaled disagreement or partial credit. Psychological Bulletin, 70(4),
213–220. https://doi.org/10.1037/h0026256

Krippendorff, K. (2018). Content analysis: An introduction to its methodology
(4th ed.). SAGE Publications.

Scott, W. A. (1955). Reliability of Content Analysis: The Case of Nominal
Scale Coding. Public Opinion Quarterly, 19(3), 321–325.
https://doi.org/10.1086/266577

Fleiss, J. L. (1971). Measuring nominal scale agreement among many raters.
Psychological Bulletin, 76(5), 378–382. https://doi.org/10.1037/h0031619
}
\seealso{
The sample \link{pi} and Krippendorff's \link{alpha}.
}
