% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kappa.R
\name{cohen_kappa}
\alias{cohen_kappa}
\alias{fleiss_kappa}
\title{Estimate agreement coefficients under a rectangular design.}
\usage{
cohen_kappa(
  x,
  alternative = c("two.sided", "greater", "less"),
  conf_level = 0.95,
  weights = "unit",
  kappa = 0,
  method = c("arcsine", "fisher", "basic"),
  skip = FALSE,
  count = NULL
)

fleiss_kappa(
  x,
  alternative = c("two.sided", "greater", "less"),
  conf_level = 0.95,
  weights = "unit",
  kappa = 0,
  method = c("arcsine", "fisher", "basic"),
  skip = FALSE,
  count = NULL
)
}
\arguments{
\item{x}{An array of raw data. Each row corresponds to an item and
each column corresponds to a judge.}

\item{alternative}{a character string specifying the alternative hypothesis,
must be one of \code{"two.sided"} (default), \code{"greater"} or \code{"less"}. Used both
for the test and the confidence interval.}

\item{conf_level}{Confidence level for the confidence interval. Defaults to
to \code{0.95}.}

\item{weights}{Choose from \code{"quadratic"}, \code{"unit"}, \code{"abs"}, or supply your
own function.}

\item{kappa}{The kappa of the null-hypothesis. Defaults to \code{0}.}

\item{method}{Method for confidence interval construction.}

\item{skip}{If \code{TRUE}, skips inference and calculates the kappa coefficient
only. Defaults to \code{FALSE}}

\item{count}{If \code{TRUE}, uses a counting algorithm. This is faster for
categorical data, but slower for continuous data.. Defaults to \code{NULL},
which evaluates to \code{TRUE} if the number of categories in the data
is less than \code{sqrt(n)}, where \code{n} is the number of rows.}
}
\value{
The weighted multirater kappa coefficient
}
\description{
We strongly recommend Cohen's kappa.
Cohen's kappa
}
\details{
Fleiss' kappa is calculatated under the assumption that

The weighted Brennan--Prediger coefficient

Krippendorff's alpha is equals Fleiss' kappa plus a small correction term.
}
\section{Functions}{
\itemize{
\item \code{fleiss_kappa}: Fleiss' kappa
}}

