% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/inference.R
\name{kappa}
\alias{kappa}
\title{Estimate a multi-rater weighted kappa under a rectangular design.}
\usage{
kappa(
  x,
  disagreement = c("nominal", "absolute", "quadratic", "hubert"),
  type = c("cohen", "fleiss"),
  g = NULL,
  alternative = c("two.sided", "greater", "less"),
  conf_level = 0.95,
  method = c("arcsine", "fisher", "basic"),
  kappa = 0,
  skip = FALSE,
  fleiss_form = FALSE
)
}
\arguments{
\item{x}{Agreement data on the wide form, ratings as rows and raters as
raters as columns. See \code{dat.zapf2016} for an example on data on the wide
form. If \code{type = "fleiss"}, the data can be on Fleiss form instead, where
the rating options are columns, but the \code{fleiss_for} must be set to true.
See \code{dat.fleiss1971} for an example on data on the Fleiss form.}

\item{disagreement}{Choose from \code{"nominal"}, \code{"absolute"}, \code{"quadratic"},
or \code{"hubert"}.}

\item{type}{The type of disagreement measure used. Defaults to \code{cohen}.}

\item{g}{The arity of the disagreement function. Defaults to \code{ncol(x)} if
\code{disagreement = "hubert"}. Defaults to \code{2} for any other disagreement.}

\item{alternative}{a character string specifying the alternative hypothesis,
must be one of \code{"two.sided"} (default), \code{"greater"} or \code{"less"}. Used both
for the test and the confidence interval.}

\item{conf_level}{Confidence level for the confidence interval. Defaults to
to \code{0.95}.}

\item{method}{Method for confidence interval construction. Defaults to the
\code{arcsine} method, which performs slightly better than the others.}

\item{kappa}{The kappa of the null-hypothesis. Defaults to \code{0}.}

\item{skip}{If \code{TRUE}, skips inference and calculates the kappa coefficient
only. Defaults to \code{FALSE}}

\item{fleiss_form}{If \code{TRUE}, the data is on Fleiss form.}
}
\value{
The weighted multi-rater kappa coefficient
}
\description{
Estimate a multi-rater weighted kappa under a rectangular design.
}
\examples{
library("agreer")

# The Zapf et al. (2016) data is on wide form, and can be used to calculate
# both Cohen's kappa and Fleiss' kappa.
kappa(dat.zapf2016, "quadratic", "cohen", g = 3, method = "basic")
kappa(dat.zapf2016, "hubert", "cohen", g = 4, method = "fisher")
kappa(dat.zapf2016, "absolute", "cohen", g = 2, method = "arcsine")

# The Fleiss (1971) data, on the other hand, is on Fleiss form, and can only
# be used for Fleiss' kappa.
kappa(dat.fleiss1971, "nominal", "fleiss", g = 2, method = "basic")
kappa(dat.fleiss1971, "hubert", "fleiss", g = 4, method = "fisher")
kappa(dat.fleiss1971, "absolute", "fleiss", g = 3, method = "arcsine")
}
