% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/agreement.R
\name{pi}
\alias{pi}
\alias{alpha}
\title{Calculate the sample pi and Krippendorff alpha}
\usage{
pi(x, loss = function(x, y) x != y)

alpha(x, loss = function(x, y) x != y)
}
\arguments{
\item{x}{Agreement data on triplet form.}

\item{loss}{The loss function to use. Must be symmetric.}
}
\value{
The sample pi coefficient or Krippendorff alpha.
}
\description{
The sample pi subsumes Scott's pi, defined for two raters, and Fleiss' kappa,
defined for \code{m} raters. Krippendorff's alpha is a simple transformation of
the sample pi, \eqn{\alpha = \pi + 1/n * (1 - \pi)}, where \eqn{n} is the
number of rows in \code{x}.
}
\details{
Under the quadratic loss, the pi coefficeint is the Pearson correlation
between paired data. Krippendorff's \link{alpha} equals the sample
\link{agreement} when every judge rates one item and every item is
judge exactly twice. The sample \link{pi} equals the sample \link{agreement}
coefficient when the marginals for all the judges are the same. In
particular, the sample \link{pi} equals Cohen's kappa when there are two
raters with no missing values and the same marginals.
}
\references{
Cohen, J. (1968). Weighted kappa: Nominal scale agreement with provision for
scaled disagreement or partial credit. Psychological Bulletin, 70(4),
213–220. https://doi.org/10.1037/h0026256

Krippendorff, K. (2018). Content analysis: An introduction to its methodology
(4th ed.). SAGE Publications.

Scott, W. A. (1955). Reliability of Content Analysis: The Case of Nominal
Scale Coding. Public Opinion Quarterly, 19(3), 321–325.
https://doi.org/10.1086/266577

Fleiss, J. L. (1971). Measuring nominal scale agreement among many raters.
Psychological Bulletin, 76(5), 378–382. https://doi.org/10.1037/h0031619
}
\seealso{
The sample \link{agreement} coefficient.
}
