% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simulation.R
\name{simulate_idm}
\alias{simulate_idm}
\title{Simulate from an item difficulty model}
\usage{
simulate_idm(
  n,
  d,
  model = c("general", "aickin"),
  true_dist,
  guessing_dist,
  ...
)
}
\arguments{
\item{n}{Number of observations to sample.}

\item{d}{A function of \code{n} that generates difficulty parameters from \code{0} to \code{1},
e.g. \code{runif}.}

\item{model}{If \code{"aickin"}, defines \code{true_dist} to be equal to the
normalized geometric mean of the guessing distributions.}

\item{true_dist}{A vector of true category probabilities. Ignored when \code{model = "aickin"}.}

\item{guessing_dist}{An array of guessing distributions, one row for every
judge.}

\item{...}{Passed to \code{d}.}
}
\value{
Simulated \code{raw} data.
}
\description{
In the generalized Aickin model, the skill-difficulties s are constand across
judges but may vary across items. The judges may have different guessing
distributions.
}
\details{
In Aickin's original model, the true distribution is equal to the normalized
geometric mean of the guessing distributions. Moreover, the skill-difficulty
parameters \code{s(1)} are binary, i.e. \code{s = 0} or \code{s(1) = 1}.
}
\examples{
 guessing_dist = rbind(
   c(0.05, 0.05, 0.5, 0.4),
   c(0.3, 0.3, 0.1, 0.3),
   c(0.3, 0.3, 0.1, 0.3)
   )

 n = 30

 # Simulate from a classical Aickin model.
 x = simulate_idm(
      n,
      d = rbinom,
      model = "aickin",
      guessing_dist = guessing_dist,
      size = 1,
      prob = 0.3)

 # Simulate from an Aickin model with specified true distribution and
 # skill parameters different from 0 and 1.
 n = 30
 true_dist = c(0.3, 0.3, 0.1, 0.3)
 y = simulate_idm(
      n,
      d = rbeta,
      model = "general",
      true_dist,
      guessing_dist,
      shape1 = 9,
      shape2 = 1)

# The true skill-difficulty parameter is E(s^2) = 0.818181.
}
