% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/knowledge.R
\name{skill}
\alias{skill}
\title{Estimate a knowledge coefficient.}
\usage{
skill(
  x,
  alternative = c("two.sided", "greater", "less"),
  conf_level = 0.95,
  model = c("bp", "fleiss", "cf", "cohen", "cbp"),
  weights = "unit",
  nu = 0,
  skip = FALSE,
  cat = length(unique(c(x)))
)
}
\arguments{
\item{x}{An array of raw data. Each row corresponds to an item and
each column corresponds to a judge.}

\item{alternative}{a character string specifying the alternative hypothesis,
must be one of \code{"two.sided"} (default), \code{"greater"} or \code{"less"}. Used both
for the test and the confidence interval.}

\item{conf_level}{Confidence level for the confidence interval. Defaults to
to \code{0.95}.}

\item{model}{The model used in the estimation of the coefficient. The
\code{"bp"}model assumes that the guessing distribution is uniform, the
\code{"fleiss"} model assumes that the guessing distribution equals the
true distribution of ratings.}

\item{weights}{Choice of weights.}

\item{nu}{The skill coefficient of the null-hypothesis. Defaults to \code{0},
which is the minimal value the skill coefficient.}

\item{skip}{If \code{TRUE}, skips inference and calculates the skill
coefficient only. Defaults to \code{FALSE}}

\item{cat}{Number of categories. Defaults the number of unique values in the
data.}
}
\value{
The skill coefficient coefficient.
}
\description{
The estimands of the coefficients in this function are approximations to the
knowledge coefficient, defined for guessing models. The approximations are
exact in some circumstances. They are similar to chance-corrected
measures of agreement, and are defined outside the context of guessing
models too.
}
\details{
Most of the coefficient admits both weighted and unweighted variants, the
exceptions being \code{bp} and \code{meancorr}.

Standard deviations and confidence sets are calculated using linearized
variance and covariance estimates. They are valid also outside the context
of guessing models.

Model \code{bp} returns the Brennan-Prediger coefficient, and is not affected by
weights. It's equivalent to \code{irrCAC::bp.raw}.

Model \code{fleiss} returns the weighted Fleiss' kappa. It's equivalent to
\code{irrCAC::fleiss.kappa.raw}.

Model \code{cohen} returns the weighted multirater Cohen kappa.

Model \code{cf} returns the weighted Cohen-Fleiss kappa.

Model \code{cbp} returns the weighted Cohen-Brennan-Prediger kappa.
}
