test_that("different values for different options, cohen, g = 3", {
  x <- dat.zapf2016
  cb <- kappa(x, "nominal", "cohen", method = "basic", g = 3)$conf.int
  ca <- kappa(x, "nominal", "cohen", method = "arcsine", g = 3)$conf.int
  cf <- kappa(x, "nominal", "cohen", method = "fisher", g = 3)$conf.int
  expect_true(ca[1] != cf[1])
  expect_true(ca[1] != cb[1])
  expect_true(cb[1] != cf[1])
  expect_true(ca[2] != cf[2])
  expect_true(ca[2] != cb[2])
  expect_true(cb[2] != cf[2])
})

test_that("different values for different options, fleiss, g = 3", {
  x <- dat.zapf2016
  fb <- kappa(x, "nominal", "fleiss", method = "basic", g = 3)$conf.int
  fa <- kappa(x, "nominal", "fleiss", method = "arcsine", g = 3)$conf.int
  ff <- kappa(x, "nominal", "fleiss", method = "fisher", g = 3)$conf.int
  expect_true(fa[1] != ff[1])
  expect_true(fa[1] != fb[1])
  expect_true(fb[1] != ff[1])
  expect_true(fa[2] != ff[2])
  expect_true(fa[2] != fb[2])
  expect_true(fb[2] != ff[2])
})

test_that("message when variance is 0", {
  x <- matrix(1, 4, 4)
  expect_message(kappa(x, "nominal", "fleiss", method = "basic", g = 3))
  expect_message(kappa(x, "nominal", "cohen", method = "basic", g = 3))
})

test_that("error when data contains NA", {
  x <- matrix(1, 4, 4)
  x[1, 2] <- NA
  expect_error(kappa(x, "nominal", "fleiss", method = "basic", g = 3))
})

test_that("ci options work", {
  x <- dat.zapf2016
  f1 <- kappa(x, "nominal", alternative = "two.sided", g = 3)$conf.int
  f2 <- kappa(x, "nominal", alternative = "greater", g = 3)$conf.int
  f3 <- kappa(x, "nominal", alternative = "less", g = 3)$conf.int
  expect_true(f1[1] != f2[1])
  expect_true(f2[1] != f3[1])
  expect_true(f3[1] != f1[1])
})

