test_that("quadratic cohen equal for all g", {
  x <- as.matrix(dat.zapf2016)
  cohen2 <- kappa_calc(x, "quadratic", "cohen", g = 2)
  cohen3 <- kappa_calc(x, "quadratic", "cohen", g = 3)
  cohen4 <- kappa_calc(x, "quadratic", "cohen", g = 4)
  expect_equal(cohen2, cohen3)
  expect_equal(cohen3, cohen4)
})

test_that("quadratic fleiss equal for all g", {
  x <- as.matrix(dat.zapf2016)
  fleiss2 <- kappa_calc(x, "quadratic", "fleiss", g = 2)
  fleiss3 <- kappa_calc(x, "quadratic", "fleiss", g = 3)
  fleiss4 <- kappa_calc(x, "quadratic", "fleiss", g = 4)
  expect_equal(fleiss2, fleiss3)
  expect_equal(fleiss3, fleiss4)
})

test_that("different values for nominal, cohen", {
  x <- as.matrix(dat.zapf2016)
  c2 <- kappa_calc(x, "nominal", "cohen", g = 2)
  c3 <- kappa_calc(x, "nominal", "cohen", g = 3)
  c4 <- kappa_calc(x, "nominal", "cohen", g = 4)
  expect_true(c2[1] != c3[1])
  expect_true(c2[1] != c4[1])
  expect_true(c3[1] != c4[1])
})

test_that("different values for different distances, cohen", {
  x <- as.matrix(dat.zapf2016)
  cn <- kappa_calc(x, "nominal", "cohen", g = 3)
  ca <- kappa_calc(x, "absolute", "cohen", g = 3)
  cq <- kappa_calc(x, "quadratic", "cohen", g = 3)
  ch <- kappa_calc(x, "hubert", "cohen", g = 3)
  expect_true(cn[1] != ca[1])
  expect_true(cq[1] != ca[1])
  expect_true(ch[1] != ca[1])
})

test_that("different values for different distances, fleiss", {
  x <- as.matrix(dat.zapf2016)
  fn <- kappa_calc(x, "nominal", "fleiss", g = 2)
  fa <- kappa_calc(x, "absolute", "fleiss", g = 2)
  fq <- kappa_calc(x, "quadratic", "fleiss", g = 2)
  fh <- kappa_calc(x, "hubert", "fleiss", g = 2)
  expect_true(fn[1] != fa[1])
  expect_true(fq[1] != fa[1])
  expect_true(fh[1] != fa[1])
})
