test_that("(dis)aggregation works", {
  x <- as.matrix(dat.fleiss1971)
  dimnames(x) <- NULL
  expect_equal(aggr(disaggr(x)), x)
})

test_that("prepare_data returns error when NA is present", {
  expect_error(prepare_date(NULL, TRUE,"cohen"))
})

test_that("prepare_data converts data to wide form", {
  x <- as.matrix(dat.fleiss1971)
  expect_equal(prepare_data(x, fleiss_form = TRUE, "fleiss"), disaggr(x))
})

test_that("prepare_data fails when calculating Cohen on Fleiss form", {
  x <- as.matrix(dat.fleiss1971)
  expect_error(prepare_data(x, fleiss_form = TRUE, "cohen"))
})

test_that("prepare_g prepares hubert correctly (g maximal)", {
  x <- dat.zapf2016
  expect_equal(kappa(x, "hubert"), kappa(x, "hubert", g = 4))
})

test_that("prepare_g prepares non-hubert correctly (g = 2)", {
  x <- dat.zapf2016
  expect_equal(kappa(x, "nominal"), kappa(x, "nominal", g = 2))
  expect_equal(kappa(x, "absolute"), kappa(x, "absolute", g = 2))
  expect_equal(kappa(x, "quadratic"), kappa(x, "quadratic", g = 2))
})
