typedef unsigned int u32;

//' Returns the unique values and their respective probabilities from a matrix.
//'
//' @param x An `arma::Mat<T>` matrix of ratings. The rows are the items rated
//'    and the columns the raters.
//' @return A tuple containing the vector of unique values and the
//'    the vector of probabilities associated with that value.

template <class T>
std::tuple<std::vector<T>, std::vector<double>> counts(arma::Mat<T> x) {
  double n = x.size();
  std::map<T, u32> counter;
  for (auto &y : x) {
    counter.emplace(y, 0);
    counter[y] += 1;
  }

  std::vector<T> uniques; uniques.reserve(counter.size());
  std::vector<double> probabilities; probabilities.reserve(counter.size());

  for(auto kv : counter) {
    uniques.push_back(kv.first);
    probabilities.push_back(kv.second / n);
  }

  return std::make_tuple(uniques, probabilities);
}

//' Returns the unique values and their respective probabilities from a matrix.
//'
//' @param x An `arma::Mat<T>` matrix of ratings. The rows are the items rated
//'    and the columns the raters.
//' @return A tuple containing the vector of unique values and the
//'    the vector of probabilities associated with that value.

u32 get_probs(arma::mat x) {
  return std::get<0>(counts(x)).size();
}

//
// std::tuple<std::vector<T>, std::vector<double>> counts_r(arma::Mat<T> x) {
//   // 1. Do the counting for each column using the previous algo.
//   // 2. Combine all the counts.
//   // 3. Return the sum of them / whatever.
// }


